COMMENT
Autogoad ignores inputs until t > delay.
After that, it monitors inputs.
When monitoring inputs, 
it generates a single "spike" when
t - t0 >= interval
where t0 is the time of "the most recent received event."
Note that "the most recent received event" may be either 
a self-event or an event received from some other spike source.
NTC
ENDCOMMENT

NEURON {
  : ARTIFICIAL_CELL means
  : that this model not only has a NET_RECEIVE block and does NOT
  : have a BREAKPOINT but is not associated with a
  : section location or numerical integrator. i.e it does not
  : refer to v or any ions or have a POINTER. It is entirely isolated
  : and depends on discrete events from the outside to affect it and
  : affects the outside only by sending discrete events.
  ARTIFICIAL_CELL Autogoad
  RANGE delay : when to start monitoring input events
  RANGE interval : how long to wait before generating an event
}

PARAMETER {
  delay = 10 (ms) : allow time for the model to settle
  interval = 20 (ms) : how long to wait before generating an event
}

ASSIGNED {
  t0 (ms)
  on (1)
}

INITIAL {
  on = 0
  t0 = t
  if (delay < 0) { delay = 0 }
  if (interval < 0) { interval = 1e9 }
  net_send(delay, 1) : to turn on
}

NET_RECEIVE (w) {
  : if monitoring
  :   check t - t0 and generate an event if necessary
  :   then update t0
  :   if this was a self-event, send a new self-event
  :      else move the existing self-event to t0+interval
  : if not monitoring
  :   start monitoring i.e.
  :     turn on
  :     update t0
  :     send self-event that returns at t0 + interval
  if (on == 1) {
    if (t - t0 >= interval) {
      net_event(t)
    }
    t0 = t
    if (flag == 1) {
      : used up our self-event, so launch another
      net_send(interval, 1)
    } else {
      : just move the existing self-event
      net_move(t0 + interval)
    }
  } else {
    if (flag == 1) {
      : got the self-event that turns it on
      on = 1
      t0 = t
      : need a new self-event
      net_send(t0 + interval, 1)
    }
  }
}
